package cn.stylefeng.guns.core.consts;

/**
 * 异常枚举编码构成常量
 * <p>
 * 异常枚举编码由3部分组成，如下：
 * <p>
 * 模块编码（2位） + 分类编码（4位） + 具体项编码（至少1位）
 * <p>
 * 模块编码和分类编码在ExpEnumCodeConstant类中声明
 *
 * @author stylefeng
 * @date 2020/6/19 20:46
 */
public interface ExpEnumConstant {

    /**
     * 模块分类编码（2位）
     * <p>
     * guns-core模块异常枚举编码
     */
    int GUNS_CORE_MODULE_EXP_CODE = 10;

    /**
     * 模块分类编码（2位）
     * <p>
     * guns-system模块异常枚举编码
     */
    int GUNS_SYS_MODULE_EXP_CODE = 20;

    /**
     * 分类编码（4位）
     * <p>
     * 认证异常枚举
     */
    int AUTH_EXCEPTION_ENUM = 1100;

    /**
     * 参数校验异常枚举
     */
    int PARAM_EXCEPTION_ENUM = 1200;

    /**
     * 授权和鉴权异常的枚举
     */
    int PERMISSION_EXCEPTION_ENUM = 1300;

    /**
     * 请求方法相关异常枚举
     */
    int REQUEST_METHOD_EXCEPTION_ENUM = 1400;

    /**
     * 请求类型相关异常枚举
     */
    int REQUEST_TYPE_EXCEPTION_ENUM = 1500;

    /**
     * 服务器内部相关异常枚举
     */
    int SERVER_EXCEPTION_ENUM = 1600;

    /**
     * 状态枚举
     */
    int STATUS_EXCEPTION_ENUM = 1700;

}
